==> haskell-should-not-typecheck-2.1.0-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-HYeVAsEucc7FTNrhsjaM7F
key:                  should-not-typecheck-2.1.0-HYeVAsEucc7FTNrhsjaM7F
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  6cc30ee9e69de009bdf73234f64158d2
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-HYeVAsEucc7FTNrhsjaM7F
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1 deepseq-1.4.8.0

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-305-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 should-not-typecheck
version:              2.1.0
visibility:           public
id:                   should-not-typecheck-2.1.0-J4xgtLnBjzS58P8JWuAwHU
key:                  should-not-typecheck-2.1.0-J4xgtLnBjzS58P8JWuAwHU
license:              BSD-3-Clause
maintainer:           message.me.on@github.com
author:               Callum Rogers
homepage:             http://github.com/CRogers/should-not-typecheck
synopsis:
    A HUnit/hspec assertion library to verify that an expression does not typecheck

description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.

category:             Testing
abi:                  45f78d91c8abe821dca1e65629c2c7d3
exposed:              True
exposed-modules:      Test.ShouldNotTypecheck
import-dirs:          /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-should-not-typecheck
hs-libraries:         HSshould-not-typecheck-2.1.0-J4xgtLnBjzS58P8JWuAwHU
depends:
    HUnit-1.6.2.0-Hv4JJKlmVQBCBbuJaEWmVH base-4.17.2.1 deepseq-1.4.8.0

haddock-interfaces:
    /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock

haddock-html:         /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
